@@ -1,3 +1,3 @@
 from lime_uow.exception import *
 from lime_uow.resrc import *
-from lime_uow.unit_of_work import UnitOfWork
+from lime_uow.unit_of_work import *
